@@ -8,6 +8,7 @@ from Script import script
 import pytz
 import random
 import os
+from .temp import *
 from datetime import datetime, date
 import string
 from typing import List
@@ -166,16 +167,7 @@ db = Database(DATABASE_URI, DATABASE_NAME)
 
 
 
-class temp(object):
-    BANNED_USERS = []
-    BANNED_CHATS = []
-    ME = None
-    CURRENT = 0
-    CANCEL = False
-    MELCOW = {}
-    U_NAME = None
-    B_NAME = None
-    SETTINGS = {}
+
 
 
 async def get_settings(group_id):
